@@ -61,12 +61,6 @@ def module_contains_display(expression):
             and hasattr(arg.parent.func, "name")
             and arg.parent.func.name == "display"
         )
-        # if (
-        #     isinstance(arg.parent, astroid.nodes.Call)
-        #     and hasattr(arg.parent.func, "name")
-        #     and arg.parent.func.name == "display"
-        # ):
-        #     contains_display_func = True
     return (
         contains_func_attribute and contains_attrname and contains_display_attr
     ) or (contains_func_attribute and contains_display_func)
@@ -81,12 +75,11 @@ def module_contains_show(expression):
         contains_show_attr = False
     contains_show_func = False
     for arg in expression.value.args:
-        if (
+        contains_show_func = (
             isinstance(arg.parent, astroid.nodes.Call)
             and hasattr(arg.parent.func, "name")
             and arg.parent.func.name == "show"
-        ):
-            contains_show_func = True
+        )
     return (contains_func_attribute and contains_attrname and contains_show_attr) or (
         contains_func_attribute and contains_show_func
     )
@@ -96,12 +89,11 @@ def module_contains_print(expression):
     contains_func_attribute = hasattr(expression.value, "func")
     contains_print_func = False
     for arg in expression.value.args:
-        if (
+        contains_print_func = (
             isinstance(arg.parent, astroid.nodes.Call)
             and hasattr(arg.parent.func, "name")
             and arg.parent.func.name == "print"
-        ):
-            contains_print_func = True
+        )
     return contains_func_attribute and contains_print_func
 
 
